<?php
$translations = array(
	'General_Locale' => 'sr_RS.UTF-8',
	'General_TranslatorName' => 'Branislav Maksin, Petar Benke, Nikola Stojković',
	'General_TranslatorEmail' => 'info@maksin.ms, petar@benke.co.uk, nikola@codingcat.com',
	'General_EnglishLanguageName' => 'Serbian',
	'General_OriginalLanguageName' => 'Srpski',
	'General_HelloUser' => 'Pozdrav, %s!',
	'General_OpenSourceWebAnalytics' => 'Web Analitika',
	'General_Dashboard' => 'Konzola',
	'General_DashboardForASpecificWebsite' => 'Konzola za određeni sajt',
	'General_MultiSitesSummary' => 'Svi sajtovi',
	'General_AllWebsitesDashboard' => 'Svi sajtovi',
	'General_API' => 'API',
	'General_Widgets' => 'Vidžeti',
	'General_Settings' => 'Podešavanja',
	'General_GiveUsYourFeedback' => 'Vaši utisci',
	'General_Unknown' => 'Nepoznato',
	'General_Never' => 'Nikad',
	'General_Required' => '%s potrebno',
	'General_NotValid' => '%s nije validno',
	'General_Id' => 'ID',
	'General_Error' => 'Greška',
	'General_Warning' => 'Upozorenje',
	'General_BackToHomepage' => 'Nazad na početnu stranu',
	'General_Yes' => 'Da',
	'General_No' => 'Ne',
	'General_Delete' => 'Obriši',
	'General_Report' => 'Izveštaj',
	'General_Edit' => 'Izmeni',
	'General_Download' => 'Preuzimanje',
	'General_Upload' => 'Okači',
	'General_Ok' => 'U redu',
	'General_Close' => 'Zatvoriti',
	'General_OrCancel' => 'ili %s prekid %s',
	'General_Logout' => 'Odjava',
	'General_Username' => 'Korisničko ime',
	'General_Description' => 'Opis',
	'General_Done' => 'Izvršeno',
	'General_PoweredBy' => 'Pokreće',
	'General_Name' => 'Ime',
	'General_Value' => 'Vrednost',
	'General_Total' => 'Ukupno',
	'General_TotalVisitsActionsRevenue' => '(Ukupno: %s poseta, %s akcija, %s zarada)',
	'General_AverageOrderValue' => 'Prosečna vrednost porudžbine',
	'General_PurchasedProducts' => 'Kupljeni proizvodi',
	'General_EcommerceOrders' => 'Elektronske porudžbine',
	'General_AbandonedCarts' => 'Napuštene korpe',
	'General_TotalRevenue' => 'Ukupan prihod',
	'General_ProductRevenue' => 'Prihodi od proizvoda',
	'General_AveragePrice' => 'Prosečna cena',
	'General_AverageQuantity' => 'Prosečan kvalitet',
	'General_UniquePurchases' => 'Jedinstvene porudžbine',
	'General_ProductConversionRate' => 'Stopa konverzije proizvoda',
	'General_Quantity' => 'Količina',
	'General_Price' => 'Cena',
	'General_Subtotal' => 'Međuzbir',
	'General_Tax' => 'Porez',
	'General_Shipping' => 'Isporuka',
	'General_Discount' => 'Popust',
	'General_Details' => 'Detalji',
	'General_Default' => 'Podrazumevana vrednost',
	'General_Visit' => 'Poseta',
	'General_FromReferrer' => 'od',
	'General_VisitorIP' => 'IP adresa posetioca',
	'General_VisitorID' => 'ID posetioca',
	'General_VisitType' => 'Tip posetioca',
	'General_VisitTypeExample' => 'Na primer, kako biste obeležili sve posetioce koji su se vratili na sajt, uključujući i one koji su već nešto kupili, API zahtev bi sadržao %s',
	'General_DaysSinceLastVisit' => 'Dana od poslednje posete',
	'General_DaysSinceFirstVisit' => 'Dana od prve posete',
	'General_DaysSinceLastEcommerceOrder' => 'Dana od poslednje elektronske porudžbine',
	'General_NumberOfVisits' => 'Broj poseta',
	'General_VisitConvertedGoal' => 'Broj poseta koje su ostvarile barem jedan cilj',
	'General_EcommerceVisitStatus' => 'Poseti status elektronske trgovine na kraju posete. Na primer, da obeležite sve posete koje su imale elektronsku porudžbinu, API zahtev bi sadržao %s',
	'General_VisitConvertedNGoals' => 'Pogledaj %s konvertovana cilja',
	'General_NewVisitor' => 'Novi posetilac',
	'General_ReturningVisitor' => 'Povratnik',
	'General_Date' => 'Datum',
	'General_Period' => 'Period',
	'General_ChooseDate' => 'Izaberite datum',
	'General_Today' => 'Danas',
	'General_Yesterday' => 'Juče',
	'General_CurrentWeek' => 'Tekuća nedelja',
	'General_CurrentMonth' => 'Tekući mesec',
	'General_CurrentYear' => 'Tekuća godina',
	'General_DateRange' => 'Vremenski period:',
	'General_DateRangeInPeriodList' => 'Vremenski period',
	'General_DateRangeFromTo' => 'Od %s do %s',
	'General_ApplyDateRange' => 'Primeni opseg datuma',
	'General_InvalidDateRange_js' => 'Neispravan opseg datuma, molimo pokušajte ponovo',
	'General_DateRangeFrom_js' => 'Od',
	'General_DateRangeTo_js' => 'Do',
	'General_PreviousDays' => 'Prethodnih %s dana (bez današnjeg dana)',
	'General_LastDays' => 'Zadnjih %s dana (uključujući današnji dan)',
	'General_LoadingData' => 'Učitavanje podataka...',
	'General_Loading_js' => 'Učitavanje...',
	'General_GoTo' => 'Idi na %s',
	'General_Next' => 'Sledeće',
	'General_Previous' => 'Prethodno',
	'General_First' => 'Prva',
	'General_Search' => 'Pretraga',
	'General_Others' => 'Ostalo',
	'General_Table' => 'Tabela',
	'General_Piechart' => 'Grafikon',
	'General_TagCloud' => 'Oblak tagova',
	'General_VBarGraph' => 'Vertikalni dijagram',
	'General_OpenInNewWindow_js' => 'Otvori u novom prozoru',
	'General_SaveImageOnYourComputer_js' => 'Ukoliko želite sa snimite sliku na vaš računar, kliknite desnim dugmetom na sliku i izaberite "Sačuvaj sliku kao..."',
	'General_Refresh' => 'Osvežite stranu',
	'General_Visitors' => 'Posetioci',
	'General_ExportThisReport' => 'Snimi ove podatke u neki drugi oblik',
	'General_ExportAsImage_js' => 'Snimi kao sliku',
	'General_Export' => 'Izvoz',
	'General_YourChangesHaveBeenSaved' => 'Vaše izmene su sačuvane',
	'General_ErrorRequest' => 'Ups… problem s zahtevom, pokušajte ponovo',
	'General_ColumnNbUniqVisitors' => 'Jedinstveni posetioci',
	'General_ColumnNbUniqVisitorsDocumentation' => 'Broj jedinstvenih posetioca koji dolaze na Vaš sajt. Svaki korisnik se računa jednom, čak i ako poseti sajt više puta dnevno.',
	'General_ColumnNbVisits' => 'Posete',
	'General_ColumnNbVisitsDocumentation' => 'Ako posetilac dođe na Vaš sajt po prvi put ili ako poseti stranu više od 30min nakon zadnjeg pregleda, onda se njegova poseta računa kao nova poseta.',
	'General_ColumnPercentageVisits' => '% poseta',
	'General_ColumnNbActions' => 'Akcije',
	'General_ColumnNbActionsDocumentation' => 'Broj akcija odrađenih od strane Vaših posetilaca. Akcije mogu biti pregledi strana, skidanje materijala sa sajta ili linkovi van sajta.',
	'General_NbActions' => 'Broj akcija',
	'General_ColumnMaxActions' => 'Maksimalan broj akcija u jednoj poseti',
	'General_ColumnSumVisitLength' => 'Ukupno vreme provedeno od strane posetilaca (u sekundama)',
	'General_ColumnLabel' => 'Kategorija',
	'General_ColumnConversionRate' => 'Stepen konverzije',
	'General_ColumnConversionRateDocumentation' => 'Procenat poseta koji su pokrenuli konverziju cilja.',
	'General_ColumnActionsPerVisit' => 'Akcije po poseti',
	'General_VisitDuration' => 'Prosečna dužina posete (u sekundama)',
	'General_ColumnAvgTimeOnSite' => 'Prosečno vreme provedeno na sajtu',
	'General_ColumnVisitDuration' => 'Dužina posete (u sekundama)',
	'General_ColumnBounceRate' => 'Stopa odbijanja',
	'General_ColumnExitRate' => 'Stepen izlaza',
	'General_ColumnPageviews' => 'Pregledane stranice',
	'General_ColumnUniquePageviews' => 'Jedinstven broj pregledanih stranica',
	'General_ColumnBounces' => 'Odbijanja',
	'General_ColumnEntrances' => 'Ulazi',
	'General_ColumnExits' => 'Izlazi',
	'General_ColumnAverageTimeOnPage' => 'Prosečno vreme na strani',
	'General_ColumnValuePerVisit' => 'Vrednost po poseti',
	'General_ColumnVisitsWithConversions' => 'Posete sa konverzijom',
	'General_YearsDays' => '%1$s godine %2$s dani',
	'General_DaysHours' => '%1$s dani %2$s sati',
	'General_HoursMinutes' => '%1$s sati %2$s minuti',
	'General_MinutesSeconds' => '%1$s min %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Sačuvaj',
	'General_ForExampleShort' => 'npr.',
	'General_YouMustBeLoggedIn' => 'Morate se prijaviti da biste pristupili ovim funkcijama',
	'General_Website' => 'Sajt',
	'General_GeneralSettings' => 'Opšta podešavanja',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Dozvoli da Piwik arhivira izveštaje svaki put kada se pregledaju iz brauzera',
	'General_ArchivingInlineHelp' => 'Za srednje i velike sajtove preporuka je da isključite ovu opciju i da podesite cron koji će procesirati Piwik izveštaje svaki sat',
	'General_ArchivingTriggerDescription' => 'Preporučljivo za velike Piwik instalacije; potrebno je da %spodesite cron%s da procesira izveštaje automatski',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Pogledajte %szvaničnu dokumentaciju%s za više informacija',
	'General_NSeconds' => '%s sekundi',
	'General_SmallTrafficYouCanLeaveDefault' => 'Za sajtove sa manjim saobraćajem možete ostaviti podrazumevanih %s sekundi i pristupiti svim izveštajima u realnom vremenu',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Za sajtove sa osrednjim ili velikim saobraćajem preporučujemo da današnje izveštaje procerirate na svakih barem pola sata (%s sekundi) ili svaki sat (%s sekundi)',
	'General_RequiresFlash' => 'Za prikaz grafikona morate imati instaliran Flash',
	'General_GraphHelp' => 'Više informacija o prikazivanju grafikona u Piwik',
	'General_NoDataForGraph' => 'Nema podataka',
	'General_NoDataForTagCloud' => 'Nema podataka',
	'General_DisplaySimpleTable' => 'Prikaži jednostavnu tabelu',
	'General_DisplayTableWithMoreMetrics' => 'Prikaži tabelu sa više metrika',
	'General_DisplayTableWithGoalMetrics' => 'Prikaži tabelu sa ciljevima',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s je projekat otvorenog koda. %3$s Ako vam se sviđa Piwik, možete pomoći. Proverite %4$s kako možete doprineti razvoju Piwik-a%5$s',
	'General_YouAreViewingDemoShortMessage' => 'Trenutno koristite demo verziju programa Piwik',
	'General_DownloadFullVersion' => '%1$sPreuzmite%2$s punu verziju! Posetite %3$s',
	'General_NewUpdatePiwikX' => 'Izašla je nova verzija: %s',
	'General_AboutPiwikX' => 'O programu Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Objavljen je Piwik %1$s. %2$s Molimo Vas da izvršite nadogradnju!%3$s (pogledajte %4$spromene%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s je na raspolaganju. Molimo vas da obavestite administratora sajta',
	'General_NewReportsWillBeProcessedByCron' => 'Ako Piwik arhiviranje nije pokrenuto od strane brauzera, onda će nove izveštaje procesirati crontab',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Izveštaji će u tom slučaju biti procesirani na svakih sat vremena',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Ukoliko je arhiviranje previše brzo, možete podesiti crontab da radi češće',
	'General_BackToPiwik' => 'Nazad na Piwik',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Maj',
	'General_ShortMonth_6' => 'Jun',
	'General_ShortMonth_7' => 'Jul',
	'General_ShortMonth_8' => 'Avg',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Januar',
	'General_LongMonth_2' => 'Februar',
	'General_LongMonth_3' => 'Mart',
	'General_LongMonth_4' => 'April',
	'General_LongMonth_5' => 'Maj',
	'General_LongMonth_6' => 'Jun',
	'General_LongMonth_7' => 'Jul',
	'General_LongMonth_8' => 'Avgust',
	'General_LongMonth_9' => 'Septembar',
	'General_LongMonth_10' => 'Oktobar',
	'General_LongMonth_11' => 'Novembar',
	'General_LongMonth_12' => 'Decembar',
	'General_ShortDay_1' => 'Pon',
	'General_ShortDay_2' => 'Uto',
	'General_ShortDay_3' => 'Sre',
	'General_ShortDay_4' => 'Čet',
	'General_ShortDay_5' => 'Pet',
	'General_ShortDay_6' => 'Sub',
	'General_ShortDay_7' => 'Ned',
	'General_LongDay_1' => 'Ponedeljak',
	'General_LongDay_2' => 'Utorak',
	'General_LongDay_3' => 'Sreda',
	'General_LongDay_4' => 'Četvrtak',
	'General_LongDay_5' => 'Petak',
	'General_LongDay_6' => 'Subota',
	'General_LongDay_7' => 'Nedelja',
	'General_Daily' => 'Dnevno',
	'General_Weekly' => 'Nedeljno',
	'General_Monthly' => 'Mesečno',
	'General_ConfigFileIsNotWritable' => 'U Piwik datoteku sa podešavanjima %s nije moguće pisati tako da neke od vaših izmena nije moguće sačuvati. %s Molimo vas da promenite dozvole nad ovom datotekom kako bi se u nju moglo pisati.',
	'General_ExceptionDatabaseVersion' => 'Vaša %1$s verzija je %2$s ali Piwik zahteva barem %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Vaša %1$s klijentska verzija je %2$s što je nekompatibilno sa serverskom verzijom %3$s.',
	'General_ExceptionMissingFile' => 'Nedostajuća datoteka: %s',
	'General_ExceptionFilesizeMismatch' => 'Veličina datoteke se ne poklapa: %1$s (očekivana veličina: %2$s, zatečena: %3$s)',
	'General_ExceptionFileIntegrity' => 'Provera integriteta nije uspela: %s',
	'General_ExceptionNonceMismatch' => 'Nije moguće proveriti sigurnosni token na ovoj formi.',
	'General_PleaseSpecifyValue' => 'Molimo vas da navedete vrednost za \'%s\'.',
	'General_ExceptionMethodNotFound' => 'Metod \'%s\' ne postoji ili nije na raspolaganju u modulu \'%s\'.',
	'General_ExceptionInvalidRendererFormat' => 'Format \'%s\' nije validan. Pokušajte neki od ovih: %s.',
	'General_ExceptionInvalidPeriod' => 'Period \'%s\' nije podržan. Pokušajte neki od ovih: %s.',
	'General_ExceptionInvalidDateRange' => 'Datum \'%s\' nije validan vremenski raspon. Trebalo bi da ima sledeći oblik: %s',
	'General_ExceptionGoalNotFound' => 'Cilj id = %s nije moguće naći.',
	'General_ExceptionUndeletableFile' => 'Nije moguće obrisati %s',
	'General_ExceptionPrivilege' => 'Ne možete pristupiti resursu pošto to zahteva %s.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Ne možete pristupiti resursu pošto to zahteva %s za barem jedan sajt.',
	'General_ExceptionPrivilegeAccessWebsite' => 'Ne možete pristupiti resursu pošto to zahteva %s za sajt id = %d.',
	'General_ExceptionInvalidArchiveTimeToLive' => 'Vreme mora biti predstavljeno brojem sekundi koje je veće od nule.',
	'General_ExceptionConfigurationFileNotFound' => 'Datoteka sa podešavanjima {%s} nije nađena.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Datoteka sa podešavanjima {%s} ne može biti pročitana. Vaš server možda ima onemogućen %s.',
	'General_ExceptionInvalidToken' => 'Token nije validan.',
	'General_ExceptionInvalidDateFormat' => 'Oblik datima mora da bude: %s ili bilo koja ključna reč podržana od strane funkcije %s (pogledajte %s za više informacija)',
	'General_ExceptionLanguageFileNotFound' => 'Datoteka sa jezikom \'%s\' nije nađena.',
	'General_WarningFileIntegritySkipped' => 'Otkriveno je razvojno okruženje, stoga, provera integriteta datoteka je preskočena.',
	'General_WarningFileIntegrityNoManifest' => 'Proveru integriteta datoteka nije moguće sprovesti zato što nedostaje datoteka manifest.inc.php.',
	'General_WarningFileIntegrityNoMd5file' => 'Proveru integriteta datoteka nije moguće okončati zato što nedostaje funkcija md5_file().',
	'General_FileIntegrityWarningExplanation' => 'Provera integriteta datoteka je neuspešna i prijavljene su greške. Ovo se najverovatnije desilo zbog toga što neke datoteke nisu uspešno prenesene na server. Trebalo bi da ponovo prenesete sve Piwik datoteke na server u binarnom modu i da ponovo učitate ovu stranu sve dok ne nestane poruka o greški.',
	'General_UseSMTPServerForEmail' => 'Koristi SMTP server za elektronsku poštu',
	'General_SmtpServerAddress' => 'Adresa SMTP servera',
	'General_SmtpPort' => 'SMTP port',
	'General_AuthenticationMethodSmtp' => 'Način autentikacije za SMTP',
	'General_SmtpUsername' => 'SMTP korisničko ime',
	'General_SmtpPassword' => 'SMTP lozinka',
	'General_SmtpEncryption' => 'SMTP enkripcija',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Izaberite "Da" ukoliko želite da šaljete elektronska pisma preko posebnog servera umesto putem lokalne mail funkcije.',
	'General_OptionalSmtpPort' => 'Opciono. Podrazumevana vrednost za neenkriptovani i TLS SMTP server je 25, z 465 za SSL SMTP server.',
	'General_OnlyUsedIfUserPwdIsSet' => 'Koristi se samo ako su postavljeni korisničko ime i lozinka. Kontaktirajte vašeg provajdera ako niste sigurni koji metod se koristi.',
	'General_OnlyEnterIfRequired' => 'Upišite korisničko ime samo ako to zahteva vaš SMTP server.',
	'General_OnlyEnterIfRequiredPassword' => 'Upišite lozinku samo ako to zahteva vaš SMTP server.',
	'General_WarningPasswordStored' => '%sUpozorenje:%s Ova lozinka će biti upisana u datoteku sa podešavanjima i biće vidljiva svakome ko ima pristup.',
	'General_EncryptedSmtpTransport' => 'Upišite tip enkripcije koji zahteva vaš SMTP server.',
	'General_InvalidResponse' => 'Primljeni podaci nisu validni.',
	'General_ChooseLanguage' => 'Izaberite jezik',
	'General_ChoosePeriod' => 'Izaberite period',
	'General_ChooseWebsite' => 'Izaberite sajt',
	'General_Language' => 'Jezik',
	'General_PleaseUpdatePiwik' => 'Molimo vas da nadogradite Piwik',
	'General_RequestTimedOut' => 'Vreme za zahtev %s je isteklo. Molimo pokušajte ponovo',
	'Actions_PluginDescription' => 'Izveštaji o broju prikaza stranica, izlaznih linkova i preuzimanja. Praćenje izlaznih linkova i preuzimanja je automatsko!',
	'Actions_Actions' => 'Akcije',
	'Actions_SubmenuPages' => 'Stranice',
	'Actions_SubmenuPagesEntry' => 'Ulazne stranice',
	'Actions_SubmenuPagesExit' => 'Izlazne stranice',
	'Actions_SubmenuPageTitles' => 'Naslovi stranica',
	'Actions_SubmenuOutlinks' => 'Izlazni linkovi',
	'Actions_SubmenuDownloads' => 'Preuzimanja',
	'Actions_PagesReportDocumentation' => 'Ovaj izveštaj sadrži informacije o linkovima koji su posećeni. %s Tabela je organizovana hijerarhijski, linkovi su prikazani u vidu foldera.',
	'Actions_PageTitlesReportDocumentation' => 'Ovaj izveštaj sadrži informacije o naslovima stranica koje su posećene. %s Naslov stranice je HTML %s tag koji većina pregledača prikazuje umesto svog naslova.',
	'Actions_OutlinksReportDocumentation' => 'Ovaj izveštaj pokazuje hijerarhijsku listu odlaznih linkova koje su Vaši posetioci kliknuli.',
	'Actions_OutlinkDocumentation' => 'Odlazni link je link koji posetioca vodi sa Vašeg sajta (ka nekom drugom).',
	'Actions_DownloadsReportDocumentation' => 'U ovom izveštaju možete videti koje su fajlove posetioci kliknuli. %s Ono što Piwik računa kao download jeste klik na link za skidanje fajla. Bilo da je fajl skinut ili ne, to nije poznato Piwik-u.',
	'Actions_ColumnClicks' => 'Klikovi',
	'Actions_ColumnClicksDocumentation' => 'Broj klikova na ovaj link.',
	'Actions_ColumnUniqueClicks' => 'Jedinstveni klikovi',
	'Actions_ColumnUniqueClicksDocumentation' => 'Broj poseta koje uključuju klik na ovaj link. Ako je link kliknut više puta tokom jedne posete, računa se samo jedan klik.',
	'Actions_ColumnDownloads' => 'Preuzimanja',
	'Actions_ColumnUniqueDownloads' => 'Jedinstvenih preuzimanja',
	'Actions_ColumnPageName' => 'Naslov stranice',
	'Actions_ColumnPageURL' => 'Adresa stranice',
	'Actions_ColumnClickedURL' => 'Kliknutih linkova',
	'Actions_ColumnDownloadURL' => 'Download link',
	'Actions_ColumnEntryPageURL' => 'Adresa ulazne strane',
	'Actions_ColumnEntryPageTitle' => 'Naslov ulazne strane',
	'Actions_ColumnExitPageURL' => 'Adresa izlazne strane',
	'Actions_ColumnExitPageTitle' => 'Naslov izlazne strane',
	'Actions_EntryPagesReportDocumentation' => 'Ovaj izveštaj sadrži informacije o ulaznim stranicama koje su korišćene tokom određenog perioda. Izlazna stranica je prva stranica koju posetilac gleda tokom svoje posete. %s Ulazni lijkovi su prikazani u vidu foldera.',
	'Actions_ExitPagesReportDocumentation' => 'Ovaj izveštaj sadrži informacije o izlaznim stranicama koje su se desile tokom određenog perioda. Izlazna stranica je poslednja stranica koju posetilac gleda tokom svoje posete. %s Izlazni linkovi su prikazani u vidu foldera.',
	'AnonymizeIP_PluginDescription' => 'Maskiranje poslednjeg bajta IP adresa posetioca kako bi sve bilo u skladu sa vašim lokalnim zakonima i preporukama o zaštiti privatnosti.',
	'API_PluginDescription' => 'Svi podaci u Piwik-u su dostupni preko jednostavnog API-ja. Ovaj dodatak je ulazna tačka koju pozivate kako biste dobili podatke u xml, json, php, csv itd.',
	'API_QuickDocumentationTitle' => 'API kratka dokumentacija',
	'API_GenerateVisits' => 'Ukoliko nema podataka za danas, onda ih prvo generišite pomoću dodatka %s. Aktivirajte dodatak %s a onda kliknite na \'Generator posetilaca\' na stranici za Piwik administraciju.',
	'API_MoreInformation' => 'Za više informacija o Piwik API-ju molimo vas da pogledate %s uvod u Piwik API %s i %s Piwik API referenc listu %s.',
	'API_UserAuthentication' => 'Autentifikacija korisnika',
	'API_UsingTokenAuth' => 'Ukoliko želite da %s dođete do podataka putem skripta, crontaba i slično %s potrebno je da dodate parametar %s API pozivima.',
	'API_KeepTokenSecret' => 'token_auth je poverljivi podatak poput vašeg korisničkog imena i lozinke, stoga ga %s nemojte nikome pokazivati%s!',
	'API_LoadedAPIs' => 'Uspešno učitano API-ja: %s',
	'CoreAdminHome_PluginDescription' => 'Piwik administracija',
	'CoreAdminHome_MenuGeneralSettings' => 'Osnovna podešavanja',
	'CoreAdminHome_Administration' => 'Administracija',
	'CoreAdminHome_EmailServerSettings' => 'Podešavanje servera za elektronsku poštu',
	'CoreAdminHome_OptOutForYourVisitors' => 'Piwik opt-out za vaše posetioce',
	'CoreAdminHome_OptOutExplanation' => 'Piwik poštuje privatnost na Internetu. Kako biste omogućili vašim posetiocima da budu izuzeti iz Piwik analize, dodajte sledeći HTML kod na neku od stranica vaše sajta, na primer u polisu privatnosti',
	'CoreAdminHome_OptOutExplanationBis' => 'Ovaj tag će prikazati iframe element koji sadrži link za vaše posetioce koji žele da budu izuzeti iz Piwik analize tako što će imati specijalan opt-out kolačić u svom brauzeru. %s Kliknite ovde%s kako biste videli sadržaj iframe elementa.',
	'CoreAdminHome_OptOutComplete' => 'Opt-out je kompletiran; vaše posete ovom sajtu neće biti zabeležene od strane alata za web analitiku.',
	'CoreAdminHome_OptOutCompleteBis' => 'Imajte na umu da ako obrišete kolačiće ili promenite računar ili brauzer, da ćete morati ponovo da prođete kroz ovu proceduru.',
	'CoreAdminHome_YouMayOptOut' => 'Možete da izaberete da nemate jedinstven identifikacioni broj vezan za vaš računar.',
	'CoreAdminHome_YouMayOptOutBis' => 'Ukoliko želite tako, molimo vas da kliknete ispod kako biste primili opt-out kolačić.',
	'CoreAdminHome_YouAreOptedIn' => 'Trenutno ste uključeni u statistiku.',
	'CoreAdminHome_YouAreOptedOut' => 'Trenutno ste izuzeti iz statistike.',
	'CoreAdminHome_ClickHereToOptOut' => 'Kliknite za izuzeće.',
	'CoreAdminHome_ClickHereToOptIn' => 'Kliknite za uključenje.',
	'CoreAdminHome_BrandingSettings' => 'Podešavanje brendiranja',
	'CoreAdminHome_CustomLogoHelpText' => 'Možete podesiti Piwik logo koji će biti prikazan u korisničkom interfejsu i E-Mail izveštajima.',
	'CoreAdminHome_CustomLogoFeedbackInfo' => 'Ako podesite Piwik logo, možda biste bili zainteresovani da sakrijete %s link iz glavnog menija. Da to uradite, možete isključiti Feedback plugin iz %sOrganizuj Plugin-ove%s.',
	'CoreAdminHome_UseCustomLogo' => 'Koristite svoj logo',
	'CoreAdminHome_LogoUpload' => 'Izaberite logo za kačenje',
	'CoreAdminHome_LogoNotWriteable' => 'Da biste koristili svoj logo za Piwik, potrebno je da omogućite prava za pisanje logo fajlovima u okviru foldera za teme: %s',
	'CoreHome_PluginDescription' => 'Struktura izveštaja web analitike',
	'CoreHome_WebAnalyticsReports' => 'Izveštaj web analitike',
	'CoreHome_JavascriptDisabled' => 'JavaScript mora bidi uključen kako biste standardno koristili Piwik.<br />Izgleda da je JavaScript ili isključen ili nije podržan od strane vašeg brauzera.<br />Kako biste omogućili standardni prikaz, uključite JavaScript kroz podešavanja vašeg brauzera a onda %1$spokušajte ponovo%2$s.<br />',
	'CoreHome_ThereIsNoDataForThisReport' => 'Nema podataka za ovaj izveštaj.',
	'CoreHome_CategoryNoData' => 'Nema podataka u ovoj kategoriji. Probajte sa "Uključi celu populaciju".',
	'CoreHome_ShowJSCode' => 'Prikaži JavaScript kod',
	'CoreHome_PageOf_js' => '%1$s od %2$s',
	'CoreHome_PeriodDay' => 'Dan',
	'CoreHome_PeriodWeek' => 'Nedelja',
	'CoreHome_PeriodMonth' => 'Mesec',
	'CoreHome_PeriodYear' => 'Godina',
	'CoreHome_PeriodDays' => 'dana',
	'CoreHome_PeriodWeeks' => 'nedelja',
	'CoreHome_PeriodMonths' => 'meseci',
	'CoreHome_PeriodYears' => 'godina',
	'CoreHome_DaySu_js' => 'Ne',
	'CoreHome_DayMo_js' => 'Po',
	'CoreHome_DayTu_js' => 'Ut',
	'CoreHome_DayWe_js' => 'Sr',
	'CoreHome_DayTh_js' => 'Če',
	'CoreHome_DayFr_js' => 'Pe',
	'CoreHome_DaySa_js' => 'Su',
	'CoreHome_ShortDay_1_js' => 'Ned',
	'CoreHome_ShortDay_2_js' => 'Pon',
	'CoreHome_ShortDay_3_js' => 'Uto',
	'CoreHome_ShortDay_4_js' => 'Sre',
	'CoreHome_ShortDay_5_js' => 'Čet',
	'CoreHome_ShortDay_6_js' => 'Pet',
	'CoreHome_ShortDay_7_js' => 'Sub',
	'CoreHome_LongDay_1_js' => 'Nedelja',
	'CoreHome_LongDay_2_js' => 'Ponedeljak',
	'CoreHome_LongDay_3_js' => 'Utorak',
	'CoreHome_LongDay_4_js' => 'Sreda',
	'CoreHome_LongDay_5_js' => 'Četvrtak',
	'CoreHome_LongDay_6_js' => 'Petak',
	'CoreHome_LongDay_7_js' => 'Subota',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Apr',
	'CoreHome_ShortMonth_5_js' => 'Maj',
	'CoreHome_ShortMonth_6_js' => 'Jun',
	'CoreHome_ShortMonth_7_js' => 'Jul',
	'CoreHome_ShortMonth_8_js' => 'Avg',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Okt',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dec',
	'CoreHome_MonthJanuary_js' => 'Januar',
	'CoreHome_MonthFebruary_js' => 'Februar',
	'CoreHome_MonthMarch_js' => 'Mart',
	'CoreHome_MonthApril_js' => 'April',
	'CoreHome_MonthMay_js' => 'Maj',
	'CoreHome_MonthJune_js' => 'Jun',
	'CoreHome_MonthJuly_js' => 'Jul',
	'CoreHome_MonthAugust_js' => 'Avgust',
	'CoreHome_MonthSeptember_js' => 'Septembar',
	'CoreHome_MonthOctober_js' => 'Oktobar',
	'CoreHome_MonthNovember_js' => 'Novembar',
	'CoreHome_MonthDecember_js' => 'Decembar',
	'CorePluginsAdmin_PluginDescription' => 'Interfejs za upravljanje dodacima',
	'CorePluginsAdmin_Plugins' => 'Dodaci',
	'CorePluginsAdmin_PluginsManagement' => 'Upravljanje dodacima',
	'CorePluginsAdmin_MainDescription' => 'Dodaci proširuju funkcionalnost Piwik-a. Jednom instaliran dodatak se ovde može aktivirati ili deaktivirati.',
	'CorePluginsAdmin_Plugin' => 'Dodatak',
	'CorePluginsAdmin_Version' => 'Verzija',
	'CorePluginsAdmin_Status' => 'Status',
	'CorePluginsAdmin_Action' => 'Akcija',
	'CorePluginsAdmin_AuthorHomepage' => 'Autorov sajt',
	'CorePluginsAdmin_LicenseHomepage' => 'Podaci o licenci',
	'CorePluginsAdmin_PluginHomepage' => 'Sajt dodatka',
	'CorePluginsAdmin_Activated' => 'Aktivirano',
	'CorePluginsAdmin_Active' => 'Aktivno',
	'CorePluginsAdmin_Inactive' => 'Neaktivno',
	'CorePluginsAdmin_Deactivate' => 'Deaktivirati',
	'CorePluginsAdmin_Activate' => 'Aktivirati',
	'CorePluginsAdmin_MenuPlugins' => 'Dodaci',
	'CoreUpdater_PluginDescription' => 'Sistem za instaliranje novih verzija',
	'CoreUpdater_UpdateTitle' => 'Nadogradnja',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Potrebna je nadogradnja baze',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik baza podataka je zastarela i mora biti nadograđena pre nego što nastavite.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik baza će biti nadograđena sa verzije %1$s na %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Sledeći dodaci će biti nadograđeni: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Važna napomena za velike Piwik instalacije',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Ukoliko imate veliku Piwik bazu onda nadogradnja može trajati predugo da bi se izvršila iz brauzera. U tom slučaju nadogradnju možete izvršiti iz komandne linije: %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'Ukoliko niste u mogućnosti da izvršite nadogradnju iz komandne linije i ako Piwik ne uspe da se nadogradi (zbog isteka vremena na bazi, brauzeru ili bilo čega drugog), možete ručno izvršiti SQL upite.',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'Kliknite ovde kako biste videli i iskopirali SQL upite koje je potrebno izvršiti',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => 'Pažnja: ukoliko ručno vršite ove upite, za očekivati je da neki od njih neće proći. U tom slučaju jednostavno ignorišite greške i nastavite sa sledećim upitom sa spiska.',
	'CoreUpdater_ReadyToGo' => 'Da li ste spremni?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Proces nadogradnje može potrajati te vas molimo da budete strpljivi.',
	'CoreUpdater_UpgradePiwik' => 'Nadogradnja Piwik-a',
	'CoreUpdater_ErrorDIYHelp' => 'Ukoliko ste napredni korisnik i iskusite grešku prilikom nadogradnje baze:',
	'CoreUpdater_ErrorDIYHelp_1' => 'identifikujte i ispravite izvor problema (na primer, memory_limit ili max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'izvršite ostale upite',
	'CoreUpdater_ErrorDIYHelp_3' => 'ručno izmenite tabelu `option` u Piwik bazi tako što ćete za version_core postaviti vrednost verzije poslednje nadogradnje',
	'CoreUpdater_ErrorDIYHelp_4' => 'ponovo pokrenite nadogradnju (kroz brazuer ili preko komandne linije) kako biste nastavili sa procesom nadogradnje',
	'CoreUpdater_ErrorDIYHelp_5' => 'prijavite problem (i rešenje) kako bi Piwik bio poboljšan',
	'CoreUpdater_HelpMessageContent' => 'Pogledajte %1$s Piwik pitanja i odgovore %2$s koja objašnjavaju najčešće greške prilikom nadogradnje. %3$s Kontaktirajte vašeg sistemskog administratora - možda je u mogućnosti da vam pomogne oko grešaka koje su najverovatnije u domenu podešavanja servera ili MySQL-a.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritične greške nastale tokom procesa nadogradnje:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Ovo gore je sama srž poruke o grešci. Ona bi trebalo da objasni uzrok a u slučaju da vam je potrebna dalja pomoć:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Proces nadogradnje je uspešno okončan, međutim, imamo i spornih momenata nastalih tokom procesa. Molimo vas da pročitate njihove opise zarad detalja. U slučaju da vam je potrebna dalja pomoć:',
	'CoreUpdater_UpgradeComplete' => 'Nadogradnja okončana!',
	'CoreUpdater_WarningMessages' => 'Poruka upozorenja:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Greška tokom nadogradnje dodatka:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Automatski smo deaktivirali sledeće dodatke: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik je uspešno nadograđen!',
	'CoreUpdater_ContinueToPiwik' => 'Nastavite rad sa Piwik-om.',
	'CoreUpdater_UpdateAutomatically' => 'Automatska nadogradnja',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Izašla je nova verzija Piwik-a',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Možete izvršiti automatsku nadogradnju na verziju %s ili preuzeti poslednju verziju Piwik-a i izvršiti ručnu nadogradnju',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik nije u stanju da prebriše trenutnu instalaciju. Možete ili da popravite dozvole nad datotekama i direktorijumima ili da preuzmete paket sa Interneta i instalirate verziju %s ručno:',
	'CoreUpdater_DownloadX' => 'Preuzmite %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Automatska nadogradnja Piwik-a je prekinuta. Ako ne možete popraviti grešku iznad, preporučljivo je da ručno izvršite nadogradnju. %1$s Molimo Vas da proverite %2$sdokumentaciju za nadogradnju%3$s!',
	'CoreUpdater_DownloadingUpdateFromX' => 'Preuzimanje nadogradnje sa %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Raspakivanje',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Provera otpakovanih datoteka',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Kreiranje rezervne kopije datoteke sa podešavanjima u %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Instaliranje poslednje verzije',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik je uspešno nadograđen!',
	'CoreUpdater_EmptyDatabaseError' => 'Baza %s je prazna. Morate promeniti ili obrisati vašu datoteku sa podešavanjima.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Verzija %s je aktuelna.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Nekompatibilna arhiva: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Prazna arhiva.',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Arhiva nije kompletna: neke datoteke nedostaju (na primer %s).',
	'CustomVariables_PluginDescription' => 'Dodatni parametri predstavljaju uređene parove ime, vrednost koje možete sami postaviti pomoću JavaScript API funkcije setVisitCustomVariables(). U tom slučaju Piwik će prikazati koliko je bilo poseta, otvaranja stranica i ciljeva za svaki od zadatih parova.',
	'CustomVariables_CustomVariables' => 'Dodatni parametri',
	'CustomVariables_ColumnCustomVariableName' => 'Ime dodatnog parametra',
	'CustomVariables_ColumnCustomVariableValue' => 'Vrednost dodatnog parametra',
	'Dashboard_PluginDescription' => 'Vaša Konzola za web analitiku. Ovde možete personalizovati vašu Konzolu: dodajte vidžete ili im izmenite redosled. Svaki korisnik ima sopstvenu Konzolu.',
	'Dashboard_Dashboard' => 'Konzola',
	'Dashboard_DeleteWidgetConfirm' => 'Da li ste sigurni da želite da uklonite ovaj vidžet sa Konzole?',
	'Dashboard_SelectWidget' => 'Izaberite vidžet koji želite da dodate na Konzolu',
	'Dashboard_AddPreviewedWidget_js' => 'Dodaj pregledani vidžet na Konzolu',
	'Dashboard_WidgetPreview_js' => 'Prikaz vidžeta',
	'Dashboard_Close_js' => 'Zatvori',
	'Dashboard_Maximise_js' => 'Povećaj',
	'Dashboard_TitleWidgetInDashboard_js' => 'Vidžet se već nalazi na Konzoli',
	'Dashboard_TitleClickToAdd_js' => 'Kliknite kako biste ga dodali na Konzolu',
	'Dashboard_LoadingWidget_js' => 'Prikazivanje vidžeta, molimo sačekajte...',
	'Dashboard_WidgetNotFound_js' => 'Vidžet nije pronađen',
	'DBStats_PluginDescription' => 'Ovaj dodatak prikazuje iskorišćenost MySQL baze od strane Piwik tabela.',
	'DBStats_DatabaseUsage' => 'Iskorišćenost baze',
	'DBStats_MainDescription' => 'Piwik smešta sve vaše analitičke podatke u MySQL bazu. Trenutno Piwik tabele zauzimaju %s.',
	'DBStats_LearnMore' => 'Ukoliko želite da naučite više o tome kako Piwik procesira podatke i kako da ga naterate da dobro radi sa srednjim i velikim sajtovima, proučite dokumentaciju %s.',
	'DBStats_Table' => 'Tabela',
	'DBStats_RowCount' => 'Broj redova',
	'DBStats_DataSize' => 'Veličina podatka',
	'DBStats_IndexSize' => 'Veličina indeksa',
	'DBStats_TotalSize' => 'Ukupna veličina',
	'ExampleAPI_PluginDescription' => 'Primer dodatka: kako kreirati API za vaš dodatak kako biste snimili podatke u više formata bez nekog dodatnog programiranja?',
	'ExampleFeedburner_PluginDescription' => 'Primer dodatka: kako u vidžetu na konzoli prikazati vašu Feedburner pretplatu?',
	'ExampleRssWidget_PluginDescription' => 'Primer dodatka: kako napraviti novi vidžet koji će čitati RSS fid?',
	'ExampleUI_PluginDescription' => 'Primer dodatka: ovaj dodatak pokazuje kako se radi sa Piwik UI (pravljenje tabela, grafikona itd.)',
	'Feedback_PluginDescription' => 'Pošaljite vaša opažanja Piwik timu. Podelite sa nama vaše ideje i sugestije!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Da li želite da prijavite grešku u programu ili imate neku želju?',
	'Feedback_ViewAnswersToFAQ' => 'Pogledajte odgovore na %s najčešće postavljana pitanja%s',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Zašto se posete mom sajtu ne beleže?',
	'Feedback_HowToExclude' => 'Kako da sebe izostavim iz statistike?',
	'Feedback_WhyWrongCountry' => 'Zašto Piwik prikazuje moje posete pod pogrešnom zemljom?',
	'Feedback_HowToAnonymizeIP' => 'Kako da zamaskiram IP adrese posetilaca u mojoj bazi?',
	'Feedback_VisitTheForums' => 'Posetite %s Forum%s',
	'Feedback_LearnWaysToParticipate' => 'Pogledajte kako sve možete da %s uzmete učešće%s',
	'Feedback_SpecialRequest' => 'Da li imate neki specijalan zahtev za Piwik tim?',
	'Feedback_ContactThePiwikTeam' => 'Kontaktirajte Piwik tim!',
	'Feedback_IWantTo' => 'Želim da:',
	'Feedback_CategoryShareStory' => 'Podelite sa drugima uspešnu Piwik priču',
	'Feedback_CategorySponsor' => 'Sponzorišite Piwik',
	'Feedback_CategoryHire' => 'Unajmite konsultanta za Piwik',
	'Feedback_CategorySecurity' => 'Prijavite sigurnosni propust',
	'Feedback_MyEmailAddress' => 'Moja elektronska adresa:',
	'Feedback_MyMessage' => 'Moja poruka:',
	'Feedback_DetailsPlease' => '(molimo vas da budete detaljni)',
	'Feedback_SendFeedback' => 'Pošaljite vaše zapažanje',
	'Feedback_ManuallySendEmailTo' => 'Molimo vas da pošaljete poruku na',
	'Feedback_MessageSent' => 'Vaša poruka je poslata Piwik timu',
	'Feedback_ThankYou' => 'Hvala vam što nam pomažete da učinimo Piwik boljim!',
	'Feedback_ThePiwikTeam' => 'Piwik tim',
	'Feedback_ExceptionBodyLength' => 'Poruka mora imati barem %s znakova.',
	'Feedback_ExceptionNoUrls' => 'Poruka ne sme sadržati web adresu kako bismo izbegli neželjene reklamne poruke',
	'Goals_Goals' => 'Ciljevi',
	'Goals_GoalsOverview' => 'Pregled ciljeva',
	'Goals_GoalsManagement' => 'Upravljanje ciljevima',
	'Goals_ConversionsOverviewBy' => 'Pregled ispunjenja ciljeva po tipu posete',
	'Goals_GoalConversionsBy' => 'Ispunjenje cilja %s po tipu posete',
	'Goals_ViewGoalsBy' => 'Prikaz ciljeva po %s',
	'Goals_PluginDescription' => 'Zadajte ciljeve i pogledajte izveštaje o ispunjenju vaših ciljeva: razvoj tokom vremena, zarada po poseti, ispunjenju po referenci, ključnim rečima itd.',
	'Goals_ColumnConversions' => 'Ispunjenja',
	'Goals_ColumnRevenue' => 'Prihod',
	'Goals_GoalX' => 'Cilj %s',
	'Goals_GoalConversion' => 'Ispunjenje cilja',
	'Goals_OverallRevenue' => '%s ukupna zarada',
	'Goals_OverallConversionRate' => '%s ukupan stepen ispunjenja (posete sa ispunjenim ciljem)',
	'Goals_Conversions' => '%s ispunjenja',
	'Goals_ConversionRate' => '%s stepen ispunjenja',
	'Goals_NoGoalsNeedAccess' => 'Samo adminitartor i superkorisnik mogu dodavati ciljeve za dati sajt. Molimo vas da zatražite od vašeg Piwik administratora da postavi cilj za vaš sajt. <br>Praćenje ciljeva je odličan način za razumevanje i maksimiziranje učinka vašeg sajta!',
	'Goals_AddNewGoal' => 'Dodavanje novog cilja',
	'Goals_AddNewGoalOrEditExistingGoal' => '%sDodaj novi cilj%s ili %sizmeni%s postojeće',
	'Goals_AddGoal_js' => 'Dodaj cilj',
	'Goals_UpdateGoal_js' => 'Ažuriraj cilj',
	'Goals_DeleteGoalConfirm_js' => 'Da li ste sigurni da želite da obrišete cilj %s?',
	'Goals_CreateNewGOal' => 'Zadavanje novog cilja',
	'Goals_ViewAndEditGoals' => 'Prikaz i izmena ciljeva',
	'Goals_GoalName' => 'Naziv cilja',
	'Goals_GoalIsTriggered' => 'Cilj je dostignut',
	'Goals_GoalIsTriggeredWhen' => 'Cilj je dostignut kad',
	'Goals_WhenVisitors' => 'kad posetioci',
	'Goals_WhereThe' => 'gde',
	'Goals_Manually' => 'ručno',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'Cilj je ručno dostignut pomoću JavaScript API trackGoal()',
	'Goals_VisitUrl' => 'Poseti datu adresu (stranicu ili grupu stranica)',
	'Goals_URL' => 'URL',
	'Goals_Filename' => 'datoteka',
	'Goals_ExternalWebsiteUrl' => 'adresa eksternog sajta',
	'Goals_Download' => 'Preuzmi datoteku',
	'Goals_ClickOutlink' => 'Klik na link ka eksternom sajtu',
	'Goals_Optional' => '(opciono)',
	'Goals_WhereVisitedPageManuallyCallsJavascriptTrackerLearnMore' => 'gde posećena stranica sadrži poziv Java Script piwikTracker.trackGoal() metod (%ssaznajte više%s)',
	'Goals_DefaultRevenue' => 'Podrazumevana zarada za cilj je',
	'Goals_DefaultRevenueHelp' => 'Na primer, kontakt forma koju je popunio posetioc može u proseku biti vredna 10$. Piwik vam može pomoći da razumete koliko su dobre vaše grupe posetilaca.',
	'Goals_ConversionsOverview' => 'Prikaz ispunjenja ciljeva',
	'Goals_BestCountries' => 'Zemlje koje imaju najbolje ispunjenje ciljeva:',
	'Goals_BestKeywords' => 'Ključne reči koje imaju najbolje ispunjenje:',
	'Goals_BestReferers' => 'Reference koje imaju najbolje ispunjenje:',
	'Goals_ReturningVisitorsConversionRateIs' => 'Stepen ispunjenja od strane posetilaca koji se vraćaju je %s',
	'Goals_NewVisitorsConversionRateIs' => 'Stepen ispunjenja od strane novih posetilaca je %s',
	'Goals_Contains' => 'sadrži %s',
	'Goals_IsExactly' => 'je tačno %s',
	'Goals_MatchesExpression' => 'je u skladu sa izrazom %s',
	'Goals_CaseSensitive' => 'Obrati pažnju na velika i mala slova',
	'Goals_Pattern' => 'Obrazac',
	'Goals_ExceptionInvalidMatchingString' => 'Ukoliko izaberete \'tačno poklapanje\', izraz mora biti adresa koja počinje sa %s. Na primer, \'%s\'.',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => 'Saznajte više o %s praćenju ciljeva u Piwik-u%s u korisničkoj dokumentaciji.',
	'Installation_PluginDescription' => 'Proces instalacije Piwik-a. Instalacija se obično vrši samo jednom. Ukoliko datoteku sa podešavanjima config/config.inc.php obrišete, instalacija će početi ispočetka.',
	'Installation_Installation' => 'Instalacija',
	'Installation_InstallationStatus' => 'Status instalacije',
	'Installation_PercentDone' => '%s %% Završeno',
	'Installation_NoConfigFound' => 'Piwik datoteka sa podešavanjima nije nađena u momentu dok vi pokušavate da pristupite Piwik stranici.<br /><b>  » Kliknite ovde kako biste <a href=\'index.php\'>instalirali Piwik</a></b><br /><small>Ukoliko ste već ranije instalirali Piwik i imate neke tabele u bazi podataka, bez brige: možete nastaviti da ih koristite i zadržite postojeće podatke!</small>',
	'Installation_DatabaseSetup' => 'Podešavanje baze podataka',
	'Installation_DatabaseSetupServer' => 'server',
	'Installation_DatabaseSetupLogin' => 'korisničko ime',
	'Installation_DatabaseSetupPassword' => 'lozinka',
	'Installation_DatabaseSetupDatabaseName' => 'ime baze',
	'Installation_DatabaseSetupTablePrefix' => 'prefiks tabela',
	'Installation_DatabaseSetupAdapter' => 'adapter',
	'Installation_DatabaseErrorConnect' => 'Greška prilikom povezivanja sa bazom',
	'Installation_DatabaseCheck' => 'Provera baze',
	'Installation_DatabaseServerVersion' => 'Verzija servera',
	'Installation_DatabaseClientVersion' => 'Verzija klijenta',
	'Installation_DatabaseCreation' => 'Pravljenje baze',
	'Installation_PleaseFixTheFollowingErrors' => 'Molimo vas da ispravite sledeće greške',
	'Installation_LargePiwikInstances' => 'Pomoć u vezi velikih Piwik instalacija',
	'Installation_JsTag' => 'JavaScript kod',
	'Installation_JsTagArchivingHelp' => 'Za srednje i velike sajtove pogledajte <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">kako podesiti automatsko arhiviranje stranica</a> kako biste naterali Piwik da radi zaista brzo!',
	'Installation_Congratulations' => 'Čestitamo',
	'Installation_CongratulationsHelp' => '<p>Čestitamo! Piwik instalacija je završena.</p><p>Proverite da li je JavaScript kod ubačen na sve stranice sajta i sačekajte vaše prve posetioce!</p>',
	'Installation_ContinueToPiwik' => 'Nastavite sa upotrebom Piwik-a',
	'Installation_SetupWebsite' => 'Podešavanje sajta',
	'Installation_SetupWebSiteName' => 'naziv',
	'Installation_SetupWebSiteURL' => 'adresa',
	'Installation_Timezone' => 'vremenska zona',
	'Installation_SetupWebsiteError' => 'Došlo je do greške prilikom dodavanja sajta',
	'Installation_SetupWebsiteSetupSuccess' => 'Sajt %s je uspešno ubačen!',
	'Installation_SuperUser' => 'Superkorisnik',
	'Installation_SuperUserSetupSuccess' => 'Superkorisnik uspešno kreiran!',
	'Installation_SuperUserLogin' => 'Prijavljivanje na sistem superkorisnika',
	'Installation_Password' => 'lozinka',
	'Installation_PasswordRepeat' => 'lozinka (ponovo)',
	'Installation_Email' => 'elektronska adresa',
	'Installation_SecurityNewsletter' => 'pošaljite mi elektronsko pismo sa važnim Piwik nadogradnjama i sigurnosim upozorenjima',
	'Installation_CommunityNewsletter' => 'pošaljite mi elektronsko pismo sa nadogradnjama od strane Piwik zajednice (novi dodaci, nove opcije, itd.)',
	'Installation_PasswordDoNotMatch' => 'lozinke se ne podudaraju',
	'Installation_Requirements' => 'Piwik zahtevi',
	'Installation_Optional' => 'Opciono',
	'Installation_Legend' => 'Legenda',
	'Installation_Extension' => 'proširenje',
	'Installation_SystemCheck' => 'Provera sistema',
	'Installation_SystemCheckPhp' => 'Verzija PHP-a',
	'Installation_SystemCheckExtensions' => 'Potrebna proširenja',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik zahteva ili mysqli proširenje ili PDO i pdo_mysql proširenja.',
	'Installation_SystemCheckPdoAndMysqliHelp' => 'Na Linux serveru možete kompajlirati PHP sa sledećim opcijama: %1$s U datoteku php.ini dodajte sledeće linije: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Više informacija na: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> i <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Na Windows serveru možete dodati sledeće linije u datoteku php.ini: %s',
	'Installation_SystemCheckSplHelp' => 'Potrebno je da kompajlirate PHP sa standardnom PHP bibiotekom (SPL).',
	'Installation_SystemCheckZlibHelp' => 'Potrebno je da kompajlirate PHP sa "zlib" podrškom, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => 'Potrebno je da kompajlirate PHP sa "iconv" podrškom, --with-iconv.',
	'Installation_SystemCheckOtherExtensions' => 'Ostala proširenja',
	'Installation_SystemCheckWarnLibXmlHelp' => 'Trebalo bi da uključite "libxml" proširenje (instalirajte npr. "php-libxml" paket) zato što je ono potrebno ostalim PHP proširenjima',
	'Installation_SystemCheckWarnJsonHelp' => 'Trebalo bi da uključite "json" proširenje (instalirajte npr. "php-json" paket) zarad boljih performansi',
	'Installation_SystemCheckWarnDomHelp' => 'Trebalo bi da uključite "dom" proširenje (instalirajte npr. "php-dom" i/ili "php-xml" paket).',
	'Installation_SystemCheckWarnSimpleXMLHelp' => 'Trebalo bi da uključite "SimpleXML" proširenje (instalirajte npr. "php-simplexml" i/ili "php-xml" paket).',
	'Installation_SystemCheckWriteDirs' => 'Diektorijumi sa pristupom pisanja',
	'Installation_SystemCheckWriteDirsHelp' => 'Da biste ispravili ovu grešku na Linux serveru, ukucajte sledeće komande:',
	'Installation_SystemCheckMemoryLimit' => 'Memorijsko ograničenje',
	'Installation_SystemCheckMemoryLimitHelp' => 'Na sajtovima sa visokim saobraćajem proces arhiviranja podataka može zahtevati više memorije nego što je to trenutno dozvoljeno.<br />Promenite vrednost parametra memory_limit u php.ini datoteci ukoliko je to neophodno.',
	'Installation_SystemCheckOpenURL' => 'Otvori adresu',
	'Installation_SystemCheckOpenURLHelp' => 'Pretplate na listu slanja, obaveštenja o nadogradnjama i nadogradnja na jedan klik zahtevaju "curl" proširenje kao i da je omogućeno allow_url_fopen=On ili fsockopen()',
	'Installation_SystemCheckGD' => 'GD > 2.x (grafikoni)',
	'Installation_SystemCheckGDHelp' => 'Mali grafikoni (linije sa tačkicama) neće raditi',
	'Installation_SystemCheckFunctions' => 'Potrebne funkcije',
	'Installation_SystemCheckOtherFunctions' => 'Ostale funkcije',
	'Installation_SystemCheckTimeLimitHelp' => 'Na sajtovima sa visokim saobraćajem proces arhiviranja podataka može zahtevati više vremena nego što je to trenutno dozvoljeno.<br />Promenite vrednost parametra max_execution_time u php.ini datoteci ukoliko je to neophodno.',
	'Installation_SystemCheckMailHelp' => 'Vaši komentari i poruke za izgubljene lozinke neće biti poslate bez mail() funkcije.',
	'Installation_SystemCheckParseIniFileHelp' => 'Ova funkcija je isključena na vašem serveru. Piwik će pokušati da je emulira ali može da naleti na neke dalja sigurnosna ograničenja. Takođe će biti i uticaja na treker.',
	'Installation_SystemCheckGlobHelp' => 'Ova funkcija je isključena na vašem serveru. Piwik će pokušati da je emulira ali može da naleti na neke dalja sigurnosna ograničenja. Svakako će biti uticaja na funkcionalnost.',
	'Installation_SystemCheckDebugBacktraceHelp' => 'View::factory neće biti u mogućnosti da generiše prikaze za module koji ga pozivaju.',
	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik koristi anonimne funkcije',
	'Installation_SystemCheckEvalHelp' => 'QuickForm i Smarty sistem šablona su neophodni',
	'Installation_SystemCheckGzcompressHelp' => 'Potrebno je da uključite zlib proširenje i funkciju gzcompress',
	'Installation_SystemCheckGzuncompressHelp' => 'Potrebno je da uključite zlib proširenje i funkciju gzcompress',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckMbstringExtensionHelp' => 'mbstring proširenje je neophodno radi višebajtnih znakova u API odgovorima koji koriste dokumente u CSV i TSV formatima',
	'Installation_SystemCheckMbstringFuncOverloadHelp' => 'Trebalo bi da postavite vrednost mbstring.func_overload na "0".',
	'Installation_SystemCheckFileIntegrity' => 'Integritet datoteka',
	'Installation_SystemCheckAutoUpdateHelp' => 'Pažnja: Piwik nadogradnja putem jednog klika zahteva da bude omogućeno pisanje u Piwik direktorijum i njegov sadržaj',
	'Installation_SystemCheckError' => 'Došlo je do greške koja mora biti ispravljena pre nego što nastavimo',
	'Installation_SystemCheckWarning' => 'Piwik će raditi normalno ali neke funkcije neće biti dostupne',
	'Installation_SystemCheckSecureProtocol' => 'Sigurni protokol',
	'Installation_SystemCheckSecureProtocolHelp' => 'Izgleda da korstite https na vašem serveru. Sledeće linije će biti dodate u config/config.ini.php:',
	'Installation_SystemCheckTracker' => 'Status trekera',
	'Installation_SystemCheckTrackerHelp' => 'GET zahtev ka piwik.php nije uspeo. Pokušajte da stavite ovu adresu na belu listu za mod_security i HTTP Authentication.',
	'Installation_Tables' => 'Kreiranje tabela',
	'Installation_TablesWithSameNamesFound' => 'Neke %1$s tabele u vašoj bazi %2$s imaju ista imena kao i tabele koje Piwik pokušava da kreira',
	'Installation_TablesFound' => 'Sledeće tabele su pronađene u bazi podataka',
	'Installation_TablesWarningHelp' => 'Ili izaberite opciju da nastavite sa korišćenjem postojećih tabela ili opciju nove instalacije čime ćete obrisati postojeće podatke iz baze',
	'Installation_TablesReuse' => 'Nastavak korišćenja postojećih tabela',
	'Installation_TablesDelete' => 'Brisanje postojećih tabela',
	'Installation_TablesDeletedSuccess' => 'Postojeće Piwik tabele su uspešno obrisane',
	'Installation_TablesCreatedSuccess' => 'Tabele su uspešno kreirane!',
	'Installation_DatabaseCreatedSuccess' => 'Baza podataka %s je uspešno kreirana!',
	'Installation_GoBackAndDefinePrefix' => 'Vratite se korak nazad i definišite prefiks za Piwik tabele',
	'Installation_ConfirmDeleteExistingTables' => 'Da li zaista želite da obrišete tabele: %s iz vaše baze? Upozorenje: Podaci iz ovih tabela se ne mogu više povratiti!',
	'Installation_Welcome' => 'Dobrodošli!',
	'Installation_WelcomeHelp' => '<p>Piwik je alat otvorenog koda za analizu saobraćaja na sajtovima koji vam na lak način pruža željene informacije o vašim posetiocima.</p><p>Proces instalacije je podeljen na %s jednostavnih koraka i zahteva svega 5 minuta vašeg vremena.</p>',
	'Installation_ConfigurationHelp' => 'Vaša Piwik podešavanja kao da nisu dobra. Možete ili ukloniti config/config.ini.php datoteku i nastaviti sa instalacijom, ili ispraviti podešavanja u vezi sa povezivanjem na bazu podataka.',
	'Installation_ErrorInvalidState' => 'Greška: izgleda da ste pokušali da preskočite korak u instalalciji, ili vam je podrška za cookie onemogućena u vašem web čitaču, ili je Piwik datoteka sa podešavanjima već kreirana. %1$sPostarajte se da je podrška za cookie omogućena%2$s i vratite se nazad %3$s na prvu stranicu Piwik instalacije %4$s.',
	'LanguagesManager_PluginDescription' => 'Ovaj dodatak prikazuje sve raspoložive jezike za Piwik interfejs. Izabrani jezik će biti sačuvan za svakog korisnika ponaosob.',
	'LanguagesManager_AboutPiwikTranslations' => 'O Piwik prevodima',
	'Live_PluginDescription' => 'Špijunirajte vaše posetioce, uživo i u realnom vremenu!',
	'Live_LinkVisitorLog' => 'Prikaži detaljan zapis poseta',
	'Live_Actions' => 'Akcije',
	'Live_Action' => 'Akcija',
	'Live_VisitorsInRealTime' => 'Posetioci u realnom vremenu',
	'Live_VisitorLog' => 'Zapis poseta',
	'Live_Time' => 'Vreme',
	'Live_Referrer_URL' => 'Referenca',
	'Live_LastMinutes' => 'Poslednjih %s minuta',
	'Live_LastHours' => 'Poslednjih %s sati',
	'Live_GoalType' => 'Tip',
	'Live_GoalTime' => 'Prvo ostvareno vreme',
	'Live_GoalRevenue' => 'Zarada',
	'Live_GoalDetails' => 'Detalji',
	'Login_PluginDescription' => 'Dodatak za proveru prijavljivanja, čitanje podataka iz datoteke onfig/config.inc.php za superkorisnika i podataka iz baze za ostale korisnike. Može lako biti zamenjen zarad nekih novih mehanizama prijave na sistem (OpenID, htaccess itd.)',
	'Login_LoginPasswordNotCorrect' => 'Korisničko ime i lozinka nisu ispravni',
	'Login_Password' => 'Lozinka',
	'Login_PasswordRepeat' => 'Lozinka (ponovo)',
	'Login_ChangePassword' => 'Promeni lozinku',
	'Login_LoginOrEmail' => 'Korisničko ime ili elektronska adresa',
	'Login_RememberMe' => 'Zapamti me',
	'Login_LogIn' => 'Prijavljivanje',
	'Login_Logout' => 'Odjavljivanje',
	'Login_LostYourPassword' => 'Zaboravili ste lozinku?',
	'Login_RemindPassword' => 'Pošalji novu lozinku',
	'Login_PasswordResetToken' => 'Token za novu lozinku',
	'Login_PasswordReminder' => 'Molimo vas da upišete vaše korisničko ime ili elektronsku adresu. Elektronskom poštom ćete dobiti informaciju o novoj lozinki',
	'Login_PasswordsDoNotMatch' => 'Lozinka se ne poklapa',
	'Login_PasswordSuccessfullyChanged' => 'Lozinka je uspešno promenjena!',
	'Login_InvalidUsernameEmail' => 'Pogrešno korisničko ime i/ili elektronska adresa',
	'Login_InvalidOrExpiredToken' => 'Token ili nije validan ili je istekao.',
	'Login_MailTopicPasswordRecovery' => 'Oporavak lozinke',
	'Login_MailPasswordRecoveryBody' => 'Pozdrav %1$s. Primljen je zahtev za promenu lozinke od strane %2$s. Ukoliko zaista želite da promenite lozinku: 1) Idite na stranicu %3$s 2) Upišite sledeći token: %4$s 3) Popunite formu (upišite novu lozinku dva puta) i pošaljite je. Pažnja: ovaj token je validan narednih 24 sata.',
	'Login_PasswordSent' => 'Lozinka vam je upravo poslata. Proverite vašu elektronsku poštu.',
	'Login_ContactAdmin' => 'Moguć razlog: vaš hosting provajder je možda onemogućio mail() funkciju. <br />Molimo vas da kontaktirate vašeg Piwik administratora.',
	'Login_ExceptionPasswordMD5HashExpected' => 'Parametar za lozinku bi trebalo da bude MD5 hash lozinke.',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Superkorisnik ne može biti proveren putem \'%s\' mehanizma.',
	'MultiSites_PluginDescription' => 'Prikazuje statistiku za više sajtova. Ovaj dodatak je trenutno u samoj srži Piwik-a.',
	'MultiSites_Evolution' => 'Razvoj',
	'Provider_PluginDescription' => 'Izveštaj o provajderima',
	'Provider_WidgetProviders' => 'Provajderi',
	'Provider_ColumnProvider' => 'Provajder',
	'Provider_SubmenuLocationsProvider' => 'Lokacije i provajderi',
	'Referers_PluginDescription' => 'Izveštaji o referencama (dolaznim linkovima): pretraživači, ključne reči, praćenje kampanja, direktni ulasci.',
	'Referers_Referers' => 'Reference',
	'Referers_SearchEngines' => 'Pretraživači',
	'Referers_Keywords' => 'Ključne reči',
	'Referers_DirectEntry' => 'Direktni ulasci',
	'Referers_Websites' => 'Sajtovi',
	'Referers_Campaigns' => 'Kampanje',
	'Referers_Evolution' => 'Trend kroz period',
	'Referers_Type' => 'Tip dolaznog linka',
	'Referers_ColumnRefererType' => 'Tip dolaznog linka',
	'Referers_ColumnSearchEngine' => 'Pretraživač',
	'Referers_ColumnWebsite' => 'Sajt',
	'Referers_ColumnWebsitePage' => 'Stranica sajta',
	'Referers_ColumnKeyword' => 'Ključna reč',
	'Referers_ColumnCampaign' => 'Kampanja',
	'Referers_RefererName' => 'Naziv reference',
	'Referers_DetailsByRefererType' => 'Detalji u vezi sa referencom',
	'Referers_TypeDirectEntries' => 'Direktni ulasci: %s',
	'Referers_TypeSearchEngines' => 'Pretraživači: %s',
	'Referers_TypeWebsites' => 'Sajtovi: %s',
	'Referers_TypeCampaigns' => 'Kampanje: %s',
	'Referers_Distinct' => 'Različite reference po tipu',
	'Referers_DistinctSearchEngines' => 'različiti pretraživači',
	'Referers_DistinctKeywords' => 'različite ključne reči',
	'Referers_DistinctCampaigns' => 'različite kampanje',
	'Referers_DistinctWebsites' => 'različiti sajtovi',
	'Referers_UsingNDistinctUrls' => '(koristeći %s različitih adresa)',
	'Referers_SubmenuOverview' => 'Pregled',
	'Referers_SubmenuSearchEngines' => 'Pretraživači i ključne reči',
	'Referers_SubmenuWebsites' => 'Sajtovi',
	'Referers_SubmenuCampaigns' => 'Kampanje',
	'Referers_WidgetKeywords' => 'Lista ključnih reči',
	'Referers_WidgetCampaigns' => 'Lista kampanja',
	'Referers_WidgetExternalWebsites' => 'Lista eksternih sajtova',
	'Referers_WidgetSearchEngines' => 'Najbolji pretraživači',
	'Referers_WidgetOverview' => 'Pregled',
	'SecurityInfo_PluginDescription' => 'Zasnovan na PhpSecInfo PHP konzorcijuma za sigurnost, ovaj dodatak prikazuje sigurnosne informacije vašeg PHP okruženja i nudi predloge za poboljšanja.',
	'SecurityInfo_Security' => 'Sigurnost',
	'SecurityInfo_SecurityInformation' => 'Informacije o PHP sigurnosti',
	'SecurityInfo_Test' => 'Test',
	'SecurityInfo_Result' => 'Rezultat',
	'SEO_SeoRankings' => 'SEO rangiranje',
	'SEO_AlexaRank' => 'Alexa rangiranje',
	'SEO_DomainAge' => 'Starost domena',
	'SEO_Rank' => 'Rang',
	'SEO_Backlinks' => 'Povratni linkovi',
	'SEO_Pages' => 'Stranice',
	'SEO_SEORankingsFor' => 'SEO rangiranje za %s',
	'SitesManager_PluginDescription' => 'Upravljanje sajtovima: dodajte novi sajt, izmenite postojeći, pogledajte JavaScript kod koji treba ubaciti na stranice sajta. Sve akcije su dostupne i preko API-ja.',
	'SitesManager_Sites' => 'Sajtovi',
	'SitesManager_TrackingTags' => 'Kod za praćenje za %s',
	'SitesManager_WebsitesManagement' => 'Upravljanje sajtovima',
	'SitesManager_MainDescription' => 'Potrebni su vam sajtovi da biste mogli da pratite izveštaje. Dodajte, izmenite ili uklonite sajtove, pogledajte JavaScript kod koji je potrebno postaviti na vaše stranice.',
	'SitesManager_YouCurrentlyHaveAccessToNWebsites' => 'Broj sajtova na koje trenutno imate pristup: %s',
	'SitesManager_OnlyOneSiteAtTime_js' => 'U jednom trenutku možete raditi samo sa jednim sajtom. Molimo vas da snimite ili poništite izmene vezane za sajt %s.',
	'SitesManager_JsTrackingTag' => 'JavaScript kod za praćenje',
	'SitesManager_JsTrackingTagHelp' => 'Ovo je JavaScript kod koji je potrebno da postavite na sve stranice vašeg sajta',
	'SitesManager_ShowTrackingTag' => 'prikaži kod',
	'SitesManager_NoWebsites' => 'Nemate nijedan sajt',
	'SitesManager_AddSite' => 'Dodavanje novog sajta',
	'SitesManager_NotFound' => 'Nije nađen nijedan sajt za',
	'SitesManager_AliasUrlHelp' => 'Savetuje se ali nije neophodno da navedete više adresa, po jednu u svakoj liniji, koje korisnici koriste kako bi pristupili ovom sajtu. Alias adrese se neće pojaviti u izveštaju Reference > Sajtovi. Imajte na umu da nije neophodno navesti adrese sa i bez \'www\' zato što Piwik automatski vodi računa o obe.',
	'SitesManager_Urls' => 'Adresa',
	'SitesManager_MenuSites' => 'Sajtovi',
	'SitesManager_DeleteConfirm_js' => 'Da li ste sigurni da želite da obrišete sajt %s?',
	'SitesManager_ExceptionDeleteSite' => 'Nije moguće obrisati ovaj sajt pošto je to jedini prijavljeni sajt. Najpre dodajte novi sajt pa tek onda obrišite ovaj.',
	'SitesManager_ExceptionNoUrl' => 'Morate navesti barem jednu adresu po sajtu.',
	'SitesManager_ExceptionEmptyName' => 'Naziv sajta ne može biti prazan.',
	'SitesManager_ExceptionInvalidUrl' => 'Adresa \'%s\' nije validna.',
	'SitesManager_ExceptionInvalidTimezone' => 'Vremenska zona \'%s\' nije validna. Molimo vas da upišete validnu vremensku zonu.',
	'SitesManager_ExceptionInvalidCurrency' => 'Valuta \'%s\' nije validna. Molimo vas da upišete validan simbol za valutu (npr. %s)',
	'SitesManager_ExceptionInvalidIPFormat' => 'IP adresa "%s" nije u validnom obliku (npr. %s).',
	'SitesManager_SuperUserCan' => 'Superkorisnik takođe može da %s navede globalna podešavanja%s za nove sajtove.',
	'SitesManager_ExcludedIps' => 'IP adrese koje su izuzete',
	'SitesManager_GlobalListExcludedIps' => 'Globalna lista izuzetih IP adresa',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'Sledeće IP adrese će biti izuzete iz praćenja na svim sajtovima.',
	'SitesManager_ExcludedParameters' => 'Parametri za izuzeće',
	'SitesManager_GlobalListExcludedQueryParameters' => 'Globalna lista parametara za izuzeće',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => 'Sledeći parametri će biti izuzeti iz praćenja na svim sajtovima.',
	'SitesManager_ListOfQueryParametersToExclude' => 'Navedite listu parametara, jedan po liniji, koje treba izuzeti iz izveštaja',
	'SitesManager_PiwikWillAutomaticallyExcludeCommonSessionParameters' => 'Piwik će automatski izuzeti uobičajene parametre sesije (%s)',
	'SitesManager_HelpExcludedIps' => 'Navedite listu IP adresa, jednu po liniji, koje želite da izuzmete iz Piwik analize. Možete koristiti i džokere poput %1$s i %2$s',
	'SitesManager_YourCurrentIpAddressIs' => 'Vaša trenutna IP adresa je %s',
	'SitesManager_SelectACity' => 'Izaberite grad',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Izaberite grad koji se nalazi u istoj vremenskoj zoni kao i vi',
	'SitesManager_ChangingYourTimezoneWillOnlyAffectDataForward' => 'Promena vremenske zone će uticati samo na potonje podatke i neće se primenjivati retroaktivno.',
	'SitesManager_AdvancedTimezoneSupportNotFound' => 'Napredna podrška za vremenske zone nije pronađena u vašoj PHP instalaciji (podržana u PHP>=5.2). Kako bilo, još uvek možete ručno izabrati UTC pomeraj.',
	'SitesManager_UTCTimeIs' => 'UTC vreme je %s.',
	'SitesManager_Timezone' => 'Vremenska zona',
	'SitesManager_GlobalWebsitesSettings' => 'Globalna podešavanja za sajtove',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Podrazumevana vremenska zona za nove sajtove',
	'SitesManager_SelectDefaultTimezone' => 'Možete izabrati koja će biti podrazumevana vremenska zona za nove sajtove.',
	'SitesManager_Currency' => 'Valuta',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => 'Znak za valutu će biti prikazan kod prihoda po ciljevima',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Podrazumevana valuta za nove sajtove',
	'SitesManager_SelectDefaultCurrency' => 'Možete izabrati koja će biti podrazumevana valuta za nove sajtove.',
	'TranslationsAdmin_PluginDescription' => 'Pomozite u prevođenju Piwik-a na vaš jezik',
	'TranslationsAdmin_MenuTranslations' => 'Prevodi',
	'TranslationsAdmin_MenuLanguages' => 'Jezici',
	'TranslationsAdmin_LanguageCode' => 'Kod jezika',
	'TranslationsAdmin_Plugin' => 'Dodatak',
	'TranslationsAdmin_Definition' => 'Definicija',
	'TranslationsAdmin_DefaultString' => 'Osnovni jezik (Srpski)',
	'TranslationsAdmin_TranslationString' => 'Prevod (jezik: %s)',
	'TranslationsAdmin_Translations' => 'Prevodi',
	'TranslationsAdmin_FixPermissions' => 'Molimo vas da proverite dozvole nad datotekama',
	'TranslationsAdmin_AddLanguage' => 'Dodaj jezik',
	'TranslationsAdmin_Export' => 'Snimi jezik',
	'TranslationsAdmin_Import' => 'Učitaj jezik',
	'TranslationsAdmin_ShowOnlyEmpty' => 'Prikaži samo prevode koji nedostaju',
	'UserCountry_PluginDescription' => 'Izveštaj o zemljama posetilaca',
	'UserCountry_Country' => 'Zemlja',
	'UserCountry_Continent' => 'Kontinent',
	'UserCountry_DistinctCountries' => '%s različitih zemalja',
	'UserCountry_Location' => 'Lokacija',
	'UserCountry_SubmenuLocations' => 'Lokacije',
	'UserCountry_WidgetContinents' => 'Kontinenti posetilaca',
	'UserCountry_WidgetCountries' => 'Zemlje posetilaca',
	'UserCountry_country_ac' => 'Ascension Ostrva',
	'UserCountry_country_ad' => 'Andora',
	'UserCountry_country_ae' => 'Ujedinjeni Arapski Emirati',
	'UserCountry_country_af' => 'Avganistan',
	'UserCountry_country_ag' => 'Antigva i Barbuda',
	'UserCountry_country_ai' => 'Angvila',
	'UserCountry_country_al' => 'Albanija',
	'UserCountry_country_am' => 'Jermenija',
	'UserCountry_country_an' => 'Holandski Antili',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarktik',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'Američka Samoa',
	'UserCountry_country_at' => 'Austrija',
	'UserCountry_country_au' => 'Australija',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Оlandska ostrva',
	'UserCountry_country_az' => 'Azerbejdžan',
	'UserCountry_country_ba' => 'Bosna i Hercegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladeš',
	'UserCountry_country_be' => 'Belgija',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bugarska',
	'UserCountry_country_bh' => 'Bahrein',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Ostrvo Sveti Bartolomej',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneji',
	'UserCountry_country_bo' => 'Bolivija',
	'UserCountry_country_br' => 'Brazil',
	'UserCountry_country_bs' => 'Bahami',
	'UserCountry_country_bt' => 'Butan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Buve Ostrva',
	'UserCountry_country_bw' => 'Bocvana',
	'UserCountry_country_by' => 'Belorusija',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Kokos (Kiling) Ostrva',
	'UserCountry_country_cd' => 'Kongo, Demokratska Republika',
	'UserCountry_country_cf' => 'Centralnoafrička Republika',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Švajcarska',
	'UserCountry_country_ci' => 'Obala Slonovače',
	'UserCountry_country_ck' => 'Kukova Ostrva',
	'UserCountry_country_cl' => 'Čile',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Kina',
	'UserCountry_country_co' => 'Kolumbija',
	'UserCountry_country_cp' => 'Ostrvo Kliperton',
	'UserCountry_country_cr' => 'Kosta Rika',
	'UserCountry_country_cs' => 'Srbija i Crna Gora',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cv' => 'Zelenortska Ostrva',
	'UserCountry_country_cx' => 'Božićna Ostrva',
	'UserCountry_country_cy' => 'Kipar',
	'UserCountry_country_cz' => 'Češka Republika',
	'UserCountry_country_de' => 'Nemačka',
	'UserCountry_country_dg' => 'Dijego Garsija',
	'UserCountry_country_dj' => 'Džibuti',
	'UserCountry_country_dk' => 'Danska',
	'UserCountry_country_dm' => 'Dominika',
	'UserCountry_country_do' => 'Dominikanska Republika',
	'UserCountry_country_dz' => 'Alžir',
	'UserCountry_country_ea' => 'Seuta, Melilja',
	'UserCountry_country_ec' => 'Ekvador',
	'UserCountry_country_ee' => 'Estonija',
	'UserCountry_country_eg' => 'Egipat',
	'UserCountry_country_eh' => 'Zapadna Sahara',
	'UserCountry_country_er' => 'Eritreja',
	'UserCountry_country_es' => 'Španija',
	'UserCountry_country_et' => 'Etiopija',
	'UserCountry_country_eu' => 'Evropska Unija',
	'UserCountry_country_fi' => 'Finska',
	'UserCountry_country_fj' => 'Fidži',
	'UserCountry_country_fk' => 'Foklandska Ostrva (Malvini)',
	'UserCountry_country_fm' => 'Mikronezija',
	'UserCountry_country_fo' => 'Farska Ostrva',
	'UserCountry_country_fr' => 'Francuska',
	'UserCountry_country_fx' => 'Francuska, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Velika Britanija',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Gruzija',
	'UserCountry_country_gf' => 'Francuska Gvajana',
	'UserCountry_country_gg' => 'Gernsi',
	'UserCountry_country_gh' => 'Gana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Grenland',
	'UserCountry_country_gm' => 'Gambija',
	'UserCountry_country_gn' => 'Gvineja',
	'UserCountry_country_gp' => 'Gvadelupe',
	'UserCountry_country_gq' => 'Ekvatorijalna Gvineja',
	'UserCountry_country_gr' => 'Grčka',
	'UserCountry_country_gs' => 'Južna Gruzija i Južnosendvička Ostrva',
	'UserCountry_country_gt' => 'Gvatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Gvineja Bisao',
	'UserCountry_country_gy' => 'Gvajana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Herd i Mekdonaldova Ostrva',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Hrvatska',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Mađarska',
	'UserCountry_country_ic' => 'Kanarska Ostrva',
	'UserCountry_country_id' => 'Indonezija',
	'UserCountry_country_ie' => 'Irska',
	'UserCountry_country_il' => 'Izrael',
	'UserCountry_country_im' => 'Ostrvo Man',
	'UserCountry_country_in' => 'Indija',
	'UserCountry_country_io' => 'Britanska teritorija Indijskog Okeana',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran',
	'UserCountry_country_is' => 'Island',
	'UserCountry_country_it' => 'Italija',
	'UserCountry_country_je' => 'Džerzi',
	'UserCountry_country_jm' => 'Jamajka',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenija',
	'UserCountry_country_kg' => 'Kirgistan',
	'UserCountry_country_kh' => 'Kambodža',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Komorska Ostrva',
	'UserCountry_country_kn' => 'Sent Kits i Nevis',
	'UserCountry_country_kp' => 'Koreja, Demokratska Narodna Republika',
	'UserCountry_country_kr' => 'Koreja, Republika',
	'UserCountry_country_kw' => 'Kuvajt',
	'UserCountry_country_ky' => 'Kajmanska Ostrva',
	'UserCountry_country_kz' => 'Kazahstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Liban',
	'UserCountry_country_lc' => 'Sent Lucia',
	'UserCountry_country_li' => 'Lihtenštajn',
	'UserCountry_country_lk' => 'Šri Lanka',
	'UserCountry_country_lr' => 'Liberija',
	'UserCountry_country_ls' => 'Lesoto',
	'UserCountry_country_lt' => 'Litvanija',
	'UserCountry_country_lu' => 'Luksemburg',
	'UserCountry_country_lv' => 'Letonija',
	'UserCountry_country_ly' => 'Libija',
	'UserCountry_country_ma' => 'Maroko',
	'UserCountry_country_mc' => 'Monako',
	'UserCountry_country_md' => 'Moldavija',
	'UserCountry_country_me' => 'Crna Gora',
	'UserCountry_country_mf' => 'Ostrvo Sveti Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Maršalska Ostrva',
	'UserCountry_country_mk' => 'Makedonija',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Mianmar',
	'UserCountry_country_mn' => 'Mongolija',
	'UserCountry_country_mo' => 'Makao',
	'UserCountry_country_mp' => 'Severna Mariana Ostrva',
	'UserCountry_country_mq' => 'Martinik',
	'UserCountry_country_mr' => 'Mauritanija',
	'UserCountry_country_ms' => 'Monserat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauricijus',
	'UserCountry_country_mv' => 'Maldivi',
	'UserCountry_country_mw' => 'Malavi',
	'UserCountry_country_mx' => 'Meksiko',
	'UserCountry_country_my' => 'Malezija',
	'UserCountry_country_mz' => 'Mozambik',
	'UserCountry_country_na' => 'Namibija',
	'UserCountry_country_nc' => 'Nova Kaledonija',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Ostrva',
	'UserCountry_country_ng' => 'Nigerija',
	'UserCountry_country_ni' => 'Nikaragva',
	'UserCountry_country_nl' => 'Holandija',
	'UserCountry_country_no' => 'Norveška',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutralna Zona',
	'UserCountry_country_nu' => 'Niui',
	'UserCountry_country_nz' => 'Novi Zeland',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Francuska Polinezija',
	'UserCountry_country_pg' => 'Papua Nova Gvineja',
	'UserCountry_country_ph' => 'Filipini',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poljska',
	'UserCountry_country_pm' => 'Sent Pjer i Mikelon',
	'UserCountry_country_pn' => 'Pitkern',
	'UserCountry_country_pr' => 'Porto Riko',
	'UserCountry_country_ps' => 'Palestina',
	'UserCountry_country_pt' => 'Portugalija',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paragvaj',
	'UserCountry_country_qa' => 'Katar',
	'UserCountry_country_re' => 'Reunion Ostrva',
	'UserCountry_country_ro' => 'Rumunija',
	'UserCountry_country_rs' => 'Srbija',
	'UserCountry_country_ru' => 'Rusija',
	'UserCountry_country_rw' => 'Ruanda',
	'UserCountry_country_sa' => 'Saudijska Arabija',
	'UserCountry_country_sb' => 'Solomonova Ostrva',
	'UserCountry_country_sc' => 'Sejšeli',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Švedska',
	'UserCountry_country_sf' => 'Finska',
	'UserCountry_country_sg' => 'Singapur',
	'UserCountry_country_sh' => 'Sent Helena',
	'UserCountry_country_si' => 'Slovenija',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovačka',
	'UserCountry_country_sl' => 'Sijera Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalija',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'Sao Tome i Prinčipe',
	'UserCountry_country_su' => 'Sovjetski Savez',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Sirija',
	'UserCountry_country_sz' => 'Svazilend',
	'UserCountry_country_ta' => 'Ostrvo Tristan da Kunja',
	'UserCountry_country_tc' => 'Turkova i Kajko Ostrva',
	'UserCountry_country_td' => 'Čad',
	'UserCountry_country_tf' => 'Francuske Južne Teritorije',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Tajland',
	'UserCountry_country_tj' => 'Tadžikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Istočni Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunis',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Istočni Timor',
	'UserCountry_country_tr' => 'Turska',
	'UserCountry_country_tt' => 'Trinidad i Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Tajvan',
	'UserCountry_country_tz' => 'Tanzanija',
	'UserCountry_country_ua' => 'Ukrajina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Ujedinjeno Kraljevstvo',
	'UserCountry_country_um' => 'Američka Prekomorska Ostrva',
	'UserCountry_country_us' => 'Sjedinjene Američke Države',
	'UserCountry_country_uy' => 'Urugvaj',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatikan',
	'UserCountry_country_vc' => 'Sent Vinsent i Grenadini',
	'UserCountry_country_ve' => 'Venecuela',
	'UserCountry_country_vg' => 'Britanska Devičanska Ostrva',
	'UserCountry_country_vi' => 'Američka Devičanska Ostrva',
	'UserCountry_country_vn' => 'Vijetnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Valis i Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Jemen',
	'UserCountry_country_yt' => 'Majoti',
	'UserCountry_country_yu' => 'Jugoslavija',
	'UserCountry_country_za' => 'Južnoafrička Republika',
	'UserCountry_country_zm' => 'Zambija',
	'UserCountry_country_zr' => 'Zair',
	'UserCountry_country_zw' => 'Zimbabve',
	'UserCountry_country_a1' => 'Anonimni proksi',
	'UserCountry_country_a2' => 'Satelitski provajder',
	'UserCountry_country_ap' => 'Azija/Pacifički region',
	'UserCountry_country_o1' => 'Ostale zemlje',
	'UserCountry_continent_eur' => 'Evropa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_ant' => 'Antarktika',
	'UserCountry_continent_asi' => 'Azija',
	'UserCountry_continent_amn' => 'Severna Amerika',
	'UserCountry_continent_amc' => 'Centralna Amerika',
	'UserCountry_continent_ams' => 'Južna Amerika',
	'UserCountry_continent_oce' => 'Okeanija',
	'UserCountryMap_map' => 'mapa',
	'UserCountryMap_worldMap' => 'svetska mapa',
	'UserCountryMap_toggleFullscreen' => 'Ceo ekran',
	'UserSettings_PluginDescription' => 'Izveštaj o različitim parametrima vezanim za posetioce: brauzeri, operativni sistemi, dodaci, ekranske rezolucije, globalna podešavanja.',
	'UserSettings_VisitorSettings' => 'Parametri posetilaca',
	'UserSettings_BrowserFamilies' => 'Porodica brauzera',
	'UserSettings_Browsers' => 'Brauzeri',
	'UserSettings_Plugins' => 'Dodaci',
	'UserSettings_Configurations' => 'Podešavanja',
	'UserSettings_OperatingSystems' => 'Operativni sistemi',
	'UserSettings_Resolutions' => 'Rezolucije',
	'UserSettings_WideScreen' => 'Širok ekran',
	'UserSettings_ColumnBrowserFamily' => 'Porodica brauzera',
	'UserSettings_ColumnBrowser' => 'Brauzer',
	'UserSettings_ColumnBrowserVersion' => 'Verzija brauzera',
	'UserSettings_ColumnPlugin' => 'Dodatak',
	'UserSettings_ColumnConfiguration' => 'Podešavanja',
	'UserSettings_ColumnOperatingSystem' => 'Operativni sistem',
	'UserSettings_ColumnResolution' => 'Rezolucija',
	'UserSettings_ColumnTypeOfScreen' => 'Tip ekrana',
	'UserSettings_WidgetResolutions' => 'Rezolucije ekrana',
	'UserSettings_WidgetBrowsers' => 'Brauzeri posetilaca',
	'UserSettings_WidgetPlugins' => 'Lista dodataka',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Pažnja: detekcija dodataka ne radi kod Internet Explorera. Ovaj izveštaj se odnosi samo na brauzere koji nisu Internet Exlorer',
	'UserSettings_WidgetWidescreen' => 'Standardan / Širok ekran',
	'UserSettings_WidgetBrowserFamilies' => 'Brauzeri po porodicama',
	'UserSettings_WidgetOperatingSystems' => 'Operativni sistemi',
	'UserSettings_WidgetGlobalVisitors' => 'Globalna podešavanja posetilaca',
	'UserSettings_SubmenuSettings' => 'Podešavanja',
	'UsersManager_PluginDescription' => 'Rad sa korisnicima Piwik-a: dodavanje novih korisnika, izmena postojećih, rad na privilegijama. Sve akcije su dostupne i preko API-ja.',
	'UsersManager_UsersManagement' => 'Upravljanje korisnicima',
	'UsersManager_UsersManagementMainDescription' => 'Dodavanje novih i promena postojećih korisničkih naloga, dodeljivanje privilegija.',
	'UsersManager_ThereAreCurrentlyNRegisteredUsers' => 'Trenutno registrovanih korisnika: %s',
	'UsersManager_ManageAccess' => 'Kontrola pristupa',
	'UsersManager_MainDescription' => 'Određivanje koji korisnici imaju pristup sajtovima.',
	'UsersManager_Sites' => 'Sajtovi',
	'UsersManager_AllWebsites' => 'Svi sajtovi',
	'UsersManager_ApplyToAllWebsites' => 'Primeni na sve sajtove',
	'UsersManager_User' => 'Korisnik',
	'UsersManager_PrivNone' => 'Nema pristup',
	'UsersManager_PrivView' => 'Prikaz',
	'UsersManager_PrivAdmin' => 'Administracija',
	'UsersManager_ChangeAllConfirm' => 'Da li ste sigurni da želite da promenite \'%s\' privilegije na svim sajtovima?',
	'UsersManager_Password' => 'Lozinka',
	'UsersManager_Email' => 'Elektronska adresa',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'Alias superkorisnika ne može biti promenjen.',
	'UsersManager_ReportToLoadByDefault' => 'Izveštaj koji podrazumevano treba prikazati',
	'UsersManager_ReportDateToLoadByDefault' => 'Datum izveštaja koji podrazumevano treba prikazati',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'Za anonimne korisnike, datum izveštaja koji podrazumevano treba prikazati je:',
	'UsersManager_ExcludeVisitsViaCookie' => 'Isključite vaše posete pomoću kolačića',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%s Piwik ignoriše vaše posete %s %s (pronađen je specijalni kolačić u vašem brauzeru).',
	'UsersManager_YourVisitsAreNotIgnored' => '%s Piwik ne ignoriše vaše posete%s (nije pronađen kolačić u vašem brauzeru).',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Kliknite ovde kako biste obrisali kolačić i time omogućili Piwik da prati i vaše posete',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => 'Kliknite ovde kako biste postavili kolačić i time onemogućili Piwik da prati i vaše posete %s',
	'UsersManager_Edit' => 'Izmena',
	'UsersManager_AddUser' => 'Dodavanje novog korisnika',
	'UsersManager_MenuUsers' => 'Korisnici',
	'UsersManager_MenuUserSettings' => 'Tekući korisnik',
	'UsersManager_MenuAnonymousUserSettings' => 'Podešavanja anonimnih korisnika',
	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Pažnja: nemate sajtova kojima anonimni korisnici mogu da pristupe te sledeća podešavanja neće biti u upotrebi.',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Kada korisnik koji nije prijavljen pokuša da otvori Piwik, trebalo bi da se otvori:',
	'UsersManager_ChangePassword' => 'Promena lozinke',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Ukoliko želite da promenite lozinku, upišite novu. U suprotnom ostavite polje prazno',
	'UsersManager_TypeYourPasswordAgain' => 'Upišite novu lozinku ponovo',
	'UsersManager_TheLoginScreen' => 'Stranica za prijavu',
	'UsersManager_DeleteConfirm_js' => 'Da li ste sigurni da želite da obrišete korisnika %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Vaše korisničko ime ne može biti promenjeno.',
	'UsersManager_ExceptionLoginExists' => 'Korisničko ime \'%s\' već postoji.',
	'UsersManager_ExceptionEmailExists' => 'Korisnik sa elektronskom adresom \'%s\' već postoji.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Korisničko ime mora biti dugačko između %1$s i %2$s znakova i mora da sadrži samo slova, brojeve ili znkove \'_\' ili \'-\' ili \'.\' ili \'@\'',
	'UsersManager_ExceptionInvalidEmail' => 'Elektronska adresa nije validna.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Korisnik \'%s\' ne postoji pa stoga ni ne može biti obrisan.',
	'UsersManager_ExceptionAdminAnonymous' => 'Ne možete dozvoliti \'admin\' privilegije anonimnom korisniku.',
	'UsersManager_ExceptionEditAnonymous' => 'Podaci o anonimnom korisniku ne mogu biti menjani ili obrisani. Anonimni korisnik služi da bi Piwik mogao da razlikuje korisnika koji se još nije prijavio na sistem. Primera radi, svoju statistiku možete učiniti javnom tako što ćete anonimnom korisniku dozvoliti \'prikaz\' pristup.',
	'UsersManager_ExceptionSuperUser' => 'Traženi korisnik je superkorisnik i kao takav ne može biti pozvan, izmenjen ili obrisan putem API-ja. Možete ručno izmeniti podatke superkorisnika u datoteci sa Piwik podešavanjima.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Korisnik \'%s\' ne postoji.',
	'UsersManager_ExceptionAccessValues' => 'Parametar pristupa mora da ima jednu od sledećih vrednosti: [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth očekuje MD5 hash lozinku (niz od 32 znaka). Molimo vas da primenite funkciju md5() nad lozinkom pre poziva ovog metoda. Hvala.',
	'VisitFrequency_PluginDescription' => 'Statistika novih korisnika u odnosu na korisnike koji se vraćaju',
	'VisitFrequency_Evolution' => 'Trend za period',
	'VisitFrequency_ColumnReturningVisits' => 'Posetioci koji se vraćaju',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Akcije posetilaca koji se vraćaju',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'Prosečna dužina posete (u sekundama)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Stopa odbijanja posetilaca koji se vraćaju',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Prosečno akcija po ponovnoj poseti',
	'VisitFrequency_ReturnVisits' => 'Broj ponovnih poseta: %s',
	'VisitFrequency_ReturnActions' => 'Broj akcija od strane ponovnih poseta: %s',
	'VisitFrequency_ReturnAvgActions' => 'Broj akcija po ponovnoj poseti: %s',
	'VisitFrequency_ReturnAverageVisitDuration' => 'Prosečno trajanje posete od strane ponovnih posetilaca: %s',
	'VisitFrequency_ReturnBounceRate' => 'Broj poseta koje su odbijene (napustile sajt posle samo jedne stranice) %s',
	'VisitFrequency_WidgetOverview' => 'Pregled učestalosti',
	'VisitFrequency_WidgetGraphReturning' => 'Grafikon ponovnih poseta',
	'VisitFrequency_SubmenuFrequency' => 'Učestalost',
	'VisitorGenerator_PluginDescription' => 'Dodatak za generisanje lažnih poseta. Ovaj dodatak mogu koistiti Piwik korisnici ili ljudi koji rade na razvoju kako bi na lak način generisali lažne podatke i popunili izveštaje.',
	'VisitorGenerator_VisitorGenerator' => 'Generator posetilaca',
	'VisitorGenerator_Warning' => 'Upravo ćete generisati lažne posete koje će biti upisane u Piwik bazu.',
	'VisitorGenerator_NotReversible' => '%s Neće biti lako%s obrisati ove podatke iz Piwik zapisa.',
	'VisitorGenerator_AreYouSure' => 'Da li ste sigurni da želite da generišete lažne posete?',
	'VisitorGenerator_ChoiceYes' => 'Da, siguran sam!',
	'VisitorGenerator_Submit' => 'Prosledi',
	'VisitorGenerator_SelectWebsite' => 'Izaberite sajt',
	'VisitorGenerator_NbRequestsPerSec' => 'Zahteva u sekundi',
	'VisitorGenerator_DaysToCompute' => 'Broj dana',
	'VisitorInterest_PluginDescription' => 'Izveštaji o tome šta posetioce zanima: broj posećenih stranica, vreme provedeno na sajtu.',
	'VisitorInterest_VisitsPerDuration' => 'Broj poseta po dužini zadržavanja',
	'VisitorInterest_VisitsPerNbOfPages' => 'Broj poseta po broju stranica',
	'VisitorInterest_ColumnVisitDuration' => 'Dužina zadržavanja',
	'VisitorInterest_ColumnPagesPerVisit' => 'Stranica po poseti',
	'VisitorInterest_WidgetLengths' => 'Dužine poseta',
	'VisitorInterest_WidgetPages' => 'Broj stranica po poseti',
	'VisitorInterest_Engagement' => 'Zainteresovanost',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s min',
	'VisitorInterest_OnePage' => '1 stranica',
	'VisitorInterest_NPages' => '%s stranica',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$ss',
	'VisitsSummary_PluginDescription' => 'Opšte analitičke brojke: posete, jedinstveni posetioci, broj akcija, stopa odbijanja itd.',
	'VisitsSummary_VisitsSummary' => 'Sumarno',
	'VisitsSummary_NbVisits' => 'Broj poseta: %s',
	'VisitsSummary_NbUniqueVisitors' => 'Broj jedinstvenih posetilaca: %s',
	'VisitsSummary_NbActionsDescription' => 'Broj akcija (prikaza stranica, preuzimanja i odlazaka): %s',
	'VisitsSummary_AverageVisitDuration' => 'Prosečno trajanje posete: %s',
	'VisitsSummary_MaxNbActions' => 'Maksimum akcija u jednoj poseti: %s',
	'VisitsSummary_NbActionsPerVisit' => 'Akcija po poseti: %s',
	'VisitsSummary_NbVisitsBounced' => '%s posetilaca je otišlo posle samo jedne stranice',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Trend za period: %s',
	'VisitsSummary_GenerateTime' => 'Vreme generisanja izveštaja u sekundama: %s',
	'VisitsSummary_GenerateQueries' => 'Izvršeno upita: %s',
	'VisitsSummary_WidgetLastVisits' => 'Grafikon najskorijih poseta',
	'VisitsSummary_WidgetVisits' => 'Pregled poseta',
	'VisitsSummary_WidgetLastVisitors' => 'Grafikon najskorijih jedinstvenih posetilaca',
	'VisitsSummary_WidgetOverviewGraph' => 'Pregled sa grafikonom',
	'VisitsSummary_SubmenuOverview' => 'Pregled',
	'VisitTime_PluginDescription' => 'Lokalno i vreme na serveru. Znati vreme na serveru može biti korisno u slučaju zakazivanja održavanja sajta.',
	'VisitTime_LocalTime' => 'Broj poseta po lokalnom vremenu',
	'VisitTime_ServerTime' => 'Broj poseta po serverskom vremenu',
	'VisitTime_ColumnServerTime' => 'Serversko vreme',
	'VisitTime_ColumnLocalTime' => 'Lokalno vreme',
	'VisitTime_WidgetLocalTime' => 'Broj poseta po lokalnom vremenu',
	'VisitTime_WidgetServerTime' => 'Broj poseta po serverskom vremenu',
	'VisitTime_SubmenuTimes' => 'Vreme',
	'VisitTime_NHour' => '%s',
	'Widgetize_PluginDescription' => 'Ovaj dodatak vam omogućuje da na veoma jednostavan način prikažete bilo koji od Piwik vidžeta na svom blogu, sajtu, Igoogle ili Netvibes!',
	'PDFReports_ManageEmailReports' => 'Upravljanje izveštajima',
	'PDFReports_EmailReports' => 'Slanje elektronskom poštom',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'Pošalji sad',
	'PDFReports_EmailSchedule' => 'Zakaži slanje',
	'PDFReports_SendReportTo' => 'Pošalji na',
	'PDFReports_SentToMe' => 'Pošalji meni',
	'PDFReports_WeeklyScheduleHelp' => 'Nedeljno zakazivanje: izveštaj će biti poslat svakog ponedeljka.',
	'PDFReports_MonthlyScheduleHelp' => 'Mesečno zakazivanje: izveštaj će biti poslat svakog prvog u mesecu.',
	'PDFReports_AlsoSendReportToTheseEmails' => 'Izveštaje pošalji i na sledeće adrese (jedna elektronska adresa po liniji):',
	'PDFReports_PiwikReports' => 'Piwik izveštaji',
	'PDFReports_EmailHello' => 'Pozdrav,',
	'PDFReports_PleaseFindAttachedFile' => 'u prilogu se nalazi vaš %1$s izveštaj za %2$s.',
);
